@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011, 2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2014 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -1039,8 +1038,8 @@ is_compatible_scheme( const gchar *pattern, const gchar *scheme )
 }
 
 /*
- * assumuing here the same sort of optimization than for schemes
- * i.e. we assume that all selected items are must probably located
+ * assuming here the same sort of optimization than for schemes
+ * i.e. we assume that all selected items are most probably located
  * in the same dirname
  * so we take care of only checking _distinct_ dirnames against folder
  * conditions
@@ -1061,7 +1060,7 @@ is_candidate_for_folders( const NAIContext *object, guint target, GList *files )
 				gchar *dirname = na_selected_info_get_dirname( NA_SELECTED_INFO( it->data ));
 
 				if( na_core_utils_slist_count( distincts, dirname ) == 0 ){
-					g_debug( "%s: distinct dirname=%s", thisfn, dirname );
+					g_debug( "%s: examining new distinct selected dirname=%s", thisfn, dirname );
 
 					GSList *id;
 					gchar *dirname_utf8, *pattern_utf8;
@@ -1071,34 +1070,22 @@ is_candidate_for_folders( const NAIContext *object, guint target, GList *files )
 
 					distincts = g_slist_prepend( distincts, g_strdup( dirname ));
 					dirname_utf8 = g_filename_to_utf8( dirname, -1, NULL, NULL, NULL );
-					match = FALSE;
 
 					for( id = folders ; id && ok ; id = id->next ){
 						pattern = ( const gchar * ) id->data;
+						g_debug( "%s: examining new condition pattern=%s", thisfn, pattern );
 						positive = is_positive_assertion( pattern );
 						pattern_utf8 = g_filename_to_utf8( positive ? pattern : pattern+1, -1, NULL, NULL, NULL );
 						has_pattern = ( g_strstr_len( pattern_utf8, -1, "*" ) != NULL );
 
-						if( !positive || !match ){
-							if(( has_pattern && g_pattern_match_simple( pattern_utf8, dirname_utf8 )) || g_str_has_prefix( dirname_utf8, pattern_utf8 )){
-								g_debug( "%s: condition=%s, positive=%s: matched",
-										thisfn, pattern, positive ? "True":"False" );
-								if( positive ){
-									match = TRUE;
-								} else {
-									ok = FALSE;
-								}
-							/*} else {
-								g_debug( "%s: condition=%s, positive=%s: not matched",
-										thisfn, pattern_utf8, positive ? "True":"False" );*/
-							}
-						}
+						match = ( has_pattern && g_pattern_match_simple( pattern_utf8, dirname_utf8 )) ||
+								g_str_has_prefix( dirname_utf8, pattern_utf8 );
+
+						ok &= ( match && positive ) || ( !match && !positive );
 
 						g_free( pattern_utf8 );
 					}
 
-					ok &= match;
-
 					g_free( dirname_utf8 );
 				}
 
