@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009-2014 Pierre Wieser and others (see AUTHORS)
  *
  * Nautilus-Actions is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General  Public  License  as
- * published by the Free Software Foundation; either  version  2  of
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
  * Nautilus-Actions is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public  License
- * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
  * <http://www.gnu.org/licenses/>.
  *
  * Authors:
@@ -398,13 +398,13 @@ initialize_window( NAImporterAsk *editor, GtkWindow *toplevel )
 	if( NA_IS_OBJECT_ACTION( editor->private->importing )){
 		/* i18n: The action <action_label> imported from <file> has the same id than <existing_label> */
 		label = g_strdup_printf(
-				_( "The action \"%s\" imported from \"%s\" has the same identifiant than the already existing \"%s\"." ),
+				_( "The action \"%s\" imported from \"%s\" has the same identifier than the already existing \"%s\"." ),
 				imported_label, editor->private->parms->uri, existing_label );
 
 	} else {
 		/* i18n: The menu <menu_label> imported from <file> has the same id than <existing_label> */
 		label = g_strdup_printf(
-				_( "The menu \"%s\" imported from \"%s\" has the same identifiant than the already existing \"%s\"." ),
+				_( "The menu \"%s\" imported from \"%s\" has the same identifier than the already existing \"%s\"." ),
 				imported_label, editor->private->parms->uri, existing_label );
 	}
 
