@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009-2014 Pierre Wieser and others (see AUTHORS)
  *
  * Nautilus-Actions is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General  Public  License  as
- * published by the Free Software Foundation; either  version  2  of
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
  * Nautilus-Actions is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public  License
- * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
  * <http://www.gnu.org/licenses/>.
  *
  * Authors:
@@ -552,9 +552,14 @@ base_gtk_utils_table_to_grid( BaseWindow *window, const gchar *table_name )
 	na_gtk_utils_dump_children( GTK_CONTAINER( parent ));
 #endif
 
+#if !GTK_CHECK_VERSION( 3,4,0 )
 	gtk_table_get_size( GTK_TABLE( ttg.table ), &ttg.rows, &ttg.columns );
 	col_spacing = gtk_table_get_default_col_spacing( GTK_TABLE( ttg.table ));
 	row_spacing = gtk_table_get_default_row_spacing( GTK_TABLE( ttg.table ));
+#else
+	col_spacing = 6;
+	row_spacing = 6;
+#endif
 
 	ttg.grid = gtk_grid_new();
 	gtk_grid_set_column_spacing( GTK_GRID( ttg.grid ), col_spacing );
@@ -587,9 +592,7 @@ table_to_grid_foreach_cb( GtkWidget *widget, TableToGridData *ttg )
 
 	gtk_container_child_get( GTK_CONTAINER( ttg->table ), widget,
 			"left-attach", &left, "top-attach", &top, "x-options", &x_options, NULL );
-
 	gtk_widget_unparent( widget );
-
 	gtk_grid_attach( GTK_GRID( ttg->grid ), widget, left, top, 1, 1 );
 	gtk_widget_set_hexpand( widget, x_options & GTK_EXPAND );
 }
