@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011, 2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2014 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -63,9 +62,11 @@ static int toolbar_pos[] = {
 
 static void          init_toolbar( BaseWindow *window, GtkActionGroup *group, int toolbar_id );
 static void          reorder_toolbars( GtkWidget *hbox, int toolbar_id, GtkWidget *handle );
+#if !GTK_CHECK_VERSION( 3,4,0 )
 static void          on_handle_finalize( gpointer data, GObject *handle );
 static void          on_attach_toolbar( GtkHandleBox *handle, GtkToolbar *toolbar, NactMainWindow *window );
 static void          on_detach_toolbar( GtkHandleBox *handle, GtkToolbar *toolbar, NactMainWindow *window );
+#endif
 static ToolbarProps *get_toolbar_properties( int toolbar_id );
 
 /**
@@ -117,14 +118,18 @@ init_toolbar( BaseWindow *window, GtkActionGroup *group, int toolbar_id )
  * @is_active: whether this toolbar is activated or not.
  *
  * Activate or desactivate the toolbar.
+ *
+ * pwi 2013-09-07
+ * GtkHandleBox has been deprecated starting with Gtk 3.4 and there is
+ * no replacement (see https://developer.gnome.org/gtk3/stable/GtkHandleBox.html).
+ * So exit floating toolbars :(
  */
 void
 nact_main_toolbar_activate( NactMainWindow *window, int toolbar_id, GtkUIManager *ui_manager, gboolean is_active )
 {
 	static const gchar *thisfn = "nact_main_toolbar_activate";
 	ToolbarProps *props;
-	GtkWidget *toolbar, *hbox, *handle;
-	gulong attach_id, detach_id;
+	GtkWidget *toolbar, *hbox;
 
 	props = get_toolbar_properties( toolbar_id );
 	if( !props ){
@@ -135,6 +140,19 @@ nact_main_toolbar_activate( NactMainWindow *window, int toolbar_id, GtkUIManager
 	g_debug( "%s: toolbar=%p, path=%s, ref_count=%d", thisfn, ( void * ) toolbar, props->ui_path, G_OBJECT( toolbar )->ref_count );
 	hbox = base_window_get_widget( BASE_WINDOW( window ), "ToolbarHBox" );
 
+#if GTK_CHECK_VERSION( 3,4,0 )
+	if( is_active ){
+		gtk_container_add( GTK_CONTAINER( hbox ), toolbar );
+		reorder_toolbars( hbox, toolbar_id, toolbar );
+		gtk_widget_show_all( toolbar );
+
+	} else {
+		gtk_container_remove( GTK_CONTAINER( hbox ), toolbar );
+	}
+#else
+	GtkWidget *handle;
+	gulong attach_id, detach_id;
+
 	if( is_active ){
 		handle = gtk_handle_box_new();
 		gtk_handle_box_set_snap_edge( GTK_HANDLE_BOX( handle ), GTK_POS_LEFT );
@@ -158,11 +176,17 @@ nact_main_toolbar_activate( NactMainWindow *window, int toolbar_id, GtkUIManager
 		gtk_container_remove( GTK_CONTAINER( handle ), toolbar );
 		gtk_container_remove( GTK_CONTAINER( hbox ), handle );
 	}
+#endif
 
 	na_settings_set_boolean( props->prefs_key, is_active );
 }
 
 /*
+ * @hbox: the GtkHBox container
+ * @toolbar_id: toolbar identifier
+ * @handle: hbox child, which used to be a GtkHandleBox (for moveable
+ *  toolbars), and becomes the GtkToolbar itself starting with Gtk 3.4
+ *
  * reposition the newly activated toolbar in handle
  * so that the relative positions of toolbars are respected in hbox
  */
@@ -197,6 +221,7 @@ reorder_toolbars( GtkWidget *hbox, int toolbar_id, GtkWidget *handle )
 	gtk_box_reorder_child( GTK_BOX( hbox ), handle, pos );
 }
 
+#if !GTK_CHECK_VERSION( 3,4,0 )
 static void
 on_handle_finalize( gpointer data, GObject *handle )
 {
@@ -222,6 +247,7 @@ on_detach_toolbar( GtkHandleBox *handle, GtkToolbar *toolbar, NactMainWindow *wi
 
 	gtk_toolbar_set_show_arrow( toolbar, FALSE );
 }
+#endif
 
 static ToolbarProps *
 get_toolbar_properties( int toolbar_id )
