@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011, 2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2014 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -81,6 +80,7 @@ nact_menubar_file_initialize( NactMenubar *bar )
 void
 nact_menubar_file_on_update_sensitivities( const NactMenubar *bar )
 {
+	static const gchar *thisfn = "nact_menubar_file_on_update_sensitivities";
 	gboolean new_item_enabled;
 
 	/* new menu / new action
@@ -89,6 +89,11 @@ nact_menubar_file_on_update_sensitivities( const NactMenubar *bar )
 	 * we must have at least one writable provider
 	 */
 	new_item_enabled = bar->private->is_parent_writable && bar->private->has_writable_providers;
+	g_debug( "%s: is_parent_writable=%s, has_writable_providers=%s, new_item_enabled=%s",
+			thisfn,
+			bar->private->is_parent_writable ? "True":"False",
+			bar->private->has_writable_providers ? "True":"False",
+			new_item_enabled ? "True":"False" );
 	nact_menubar_enable_item( bar, "NewMenuItem", new_item_enabled );
 	nact_menubar_enable_item( bar, "NewActionItem", new_item_enabled );
 
