@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011, 2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2014 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -524,6 +523,11 @@ on_base_initialize_window( BaseWindow *window, gpointer user_data )
 		bar->private->has_writable_providers =
 				( na_io_provider_find_writable_io_provider( NA_PIVOT( bar->private->updater )) != NULL );
 
+		g_debug( "%s: na_updater_is_level_zero_writable=%s, na_io_provider_find_writable_io_provider=%s",
+				thisfn,
+				bar->private->is_level_zero_writable ? "True":"False",
+				bar->private->has_writable_providers ? "True":"False" );
+
 		/* connect to all signal which may have an influence on the menu
 		 * items sensitivity
 		 */
@@ -818,8 +822,12 @@ on_tree_view_selection_changed( BaseWindow *window, GList *selected, gpointer us
 	}
 	if( first ){
 		bar->private->is_parent_writable = na_object_is_finally_writable( first, NULL );
+		g_debug( "%s: parent of first selected is not null: is_parent_writable=%s",
+				thisfn, bar->private->is_parent_writable ? "True":"False" );
 	} else {
 		bar->private->is_parent_writable = bar->private->is_level_zero_writable;
+		g_debug( "%s: first selected is at level zero: is_level_zero_writable=%s",
+				thisfn, bar->private->is_level_zero_writable ? "True":"False" );
 	}
 
 	/* check is only an action is selected, or only profile(s) of a same action
