@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011, 2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2014 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -147,6 +146,7 @@ static void       order_mode_on_toggled( NactPreferencesEditor *editor, GtkToggl
 static void       root_menu_setup( NactPreferencesEditor *editor );
 static void       root_menu_on_toggled( GtkToggleButton *button, NactPreferencesEditor *editor );
 static void       about_item_setup( NactPreferencesEditor *editor );
+static void       about_item_set_sensitive( NactPreferencesEditor *editor );
 static void       about_item_on_toggled( GtkToggleButton *button, NactPreferencesEditor *editor );
 static void       terminal_pattern_setup( NactPreferencesEditor *editor );
 static void       terminal_pattern_on_changed( GtkEntry *entry, NactPreferencesEditor *editor );
@@ -721,6 +721,7 @@ root_menu_on_toggled( GtkToggleButton *button, NactPreferencesEditor *editor )
 
 	if( editable ){
 		editor->private->root_menu = gtk_toggle_button_get_active( button );
+		about_item_set_sensitive( editor );
 
 	} else {
 		base_gtk_utils_toggle_reset_initial_state( button );
@@ -729,6 +730,8 @@ root_menu_on_toggled( GtkToggleButton *button, NactPreferencesEditor *editor )
 
 /*
  * add an about item
+ *
+ * The About item is only added if the Nautilus-Actions root menu exists
  */
 static void
 about_item_setup( NactPreferencesEditor *editor )
@@ -741,6 +744,17 @@ about_item_setup( NactPreferencesEditor *editor )
 	base_gtk_utils_toggle_set_initial_state( BASE_WINDOW( editor ),
 			"AddAboutButton", G_CALLBACK( about_item_on_toggled ),
 			editor->private->about_item, editable, !editor->private->preferences_locked );
+
+	about_item_set_sensitive( editor );
+}
+
+static void
+about_item_set_sensitive( NactPreferencesEditor *editor )
+{
+	GtkWidget *add_about;
+
+	add_about = base_window_get_widget( BASE_WINDOW( editor ), "AddAboutButton" );
+	gtk_widget_set_sensitive( add_about, editor->private->root_menu );
 }
 
 static void
