@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011, 2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2014 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -396,15 +395,6 @@ menu_provider_get_file_items( NautilusMenuProvider *provider, GtkWidget *window,
 			return(( GList * ) NULL );
 		}
 
-#ifdef NA_MAINTAINER_MODE
-		GList *im;
-		for( im = files ; im ; im = im->next ){
-			gchar *uri = nautilus_file_info_get_uri( NAUTILUS_FILE_INFO( im->data ));
-			g_debug( "%s: uri=%s", thisfn, uri );
-			g_free( uri );
-		}
-#endif
-
 		selected = na_selected_info_get_list_from_list(( GList * ) files );
 
 		if( selected ){
@@ -414,6 +404,17 @@ menu_provider_get_file_items( NautilusMenuProvider *provider, GtkWidget *window,
 					( void * ) window,
 					( void * ) files, g_list_length( files ));
 
+#ifdef NA_MAINTAINER_MODE
+			GList *im;
+			for( im = files ; im ; im = im->next ){
+				gchar *uri = nautilus_file_info_get_uri( NAUTILUS_FILE_INFO( im->data ));
+				gchar *mimetype = nautilus_file_info_get_mime_type( NAUTILUS_FILE_INFO( im->data ));
+				g_debug( "%s: uri='%s', mimetype='%s'", thisfn, uri, mimetype );
+				g_free( mimetype );
+				g_free( uri );
+			}
+#endif
+
 			nautilus_menus_list = build_nautilus_menu(
 					NAUTILUS_ACTIONS( provider ),
 					ITEM_TARGET_SELECTION,
@@ -507,16 +508,16 @@ build_nautilus_menu( NautilusActions *plugin, guint target, GList *selection )
 	 */
 	g_object_unref( tokens );
 
-	if( target != ITEM_TARGET_TOOLBAR ){
+	if( target != ITEM_TARGET_TOOLBAR && nautilus_menu && g_list_length( nautilus_menu )){
 
 		items_create_root_menu = na_settings_get_boolean( NA_IPREFS_ITEMS_CREATE_ROOT_MENU, NULL, NULL );
 		if( items_create_root_menu ){
 			nautilus_menu = create_root_menu( plugin, nautilus_menu );
-		}
 
-		items_add_about_item = na_settings_get_boolean( NA_IPREFS_ITEMS_ADD_ABOUT_ITEM, NULL, NULL );
-		if( items_add_about_item ){
-			nautilus_menu = add_about_item( plugin, nautilus_menu );
+			items_add_about_item = na_settings_get_boolean( NA_IPREFS_ITEMS_ADD_ABOUT_ITEM, NULL, NULL );
+			if( items_add_about_item ){
+				nautilus_menu = add_about_item( plugin, nautilus_menu );
+			}
 		}
 	}
 
@@ -534,14 +535,19 @@ build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens *
 	GList *submenu;
 	NAObjectProfile *profile;
 	NautilusMenuItem *menu_item;
+	gchar *label;
 
 	nautilus_menu = NULL;
 
 	for( it = tree ; it ; it = it->next ){
 
 		g_return_val_if_fail( NA_IS_OBJECT_ITEM( it->data ), NULL );
+		label = na_object_get_label( it->data );
+		g_debug( "%s: examining %s", thisfn, label );
 
 		if( !na_icontext_is_candidate( NA_ICONTEXT( it->data ), target, selection )){
+			g_debug( "%s: is not candidate (NAIContext): %s", thisfn, label );
+			g_free( label );
 			continue;
 		}
 
@@ -551,6 +557,9 @@ build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens *
 		 * dynamically empty - thus the NAObjectItem invalid :(
 		 */
 		if( !na_object_is_valid( item )){
+			g_debug( "%s: item %s becomes invalid after tokens expansion", thisfn, label );
+			g_object_unref( item );
+			g_free( label );
 			continue;
 		}
 
@@ -558,9 +567,9 @@ build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens *
 		 * the 'submenu' menu of nautilusMenuItem's is attached to the returned
 		 * 'item'
 		 */
-		if( NA_IS_OBJECT_MENU( item )){
+		if( NA_IS_OBJECT_MENU( it->data )){
 
-			subitems = na_object_get_items( item );
+			subitems = na_object_get_items( NA_OBJECT( it->data ));
 			g_debug( "%s: menu has %d items", thisfn, g_list_length( subitems ));
 
 			submenu = build_nautilus_menu_rec( subitems, target, selection, tokens );
@@ -575,6 +584,8 @@ build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens *
 					nautilus_menu = g_list_append( nautilus_menu, menu_item );
 				}
 			}
+			g_object_unref( item );
+			g_free( label );
 			continue;
 		}
 
@@ -586,7 +597,13 @@ build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens *
 		if( profile ){
 			menu_item = create_item_from_profile( profile, target, selection, tokens );
 			nautilus_menu = g_list_append( nautilus_menu, menu_item );
+
+		} else {
+			g_debug( "%s: %s does not have any valid candidate profile", thisfn, label );
 		}
+
+		g_object_unref( item );
+		g_free( label );
 	}
 
 	return( nautilus_menu );
@@ -960,7 +977,7 @@ add_about_item( NautilusActions *plugin, GList *menu )
 		about_item = nautilus_menu_item_new(
 				"AboutNautilusActions",
 				_( "About Nautilus-Actions" ),
-				_( "Display some informations about Nautilus-Actions" ),
+				_( "Display some information about Nautilus-Actions" ),
 				na_about_get_icon_name());
 
 		g_signal_connect_data(
