@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011, 2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2014 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -72,6 +71,7 @@ static gboolean   notoolbar        = FALSE;
 static gchar     *label_toolbar    = "";
 static gchar     *command          = "";
 static gchar     *parameters       = "";
+static gchar     *workingdir       = "";
 static gchar    **basenames_array  = NULL;
 static gboolean   matchcase        = FALSE;
 static gboolean   nocase           = FALSE;
@@ -109,6 +109,7 @@ static const ArgFromDataDef st_arg_from_data_def[] = {
 		{ action_data_groups,  NA_FACTORY_OBJECT_ACTION_GROUP,     NAFO_DATA_TOOLBAR_LABEL,      &label_toolbar },
 		{ profile_data_groups, NA_FACTORY_OBJECT_PROFILE_GROUP,    NAFO_DATA_PATH,               &command },
 		{ profile_data_groups, NA_FACTORY_OBJECT_PROFILE_GROUP,    NAFO_DATA_PARAMETERS,         &parameters },
+		{ profile_data_groups, NA_FACTORY_OBJECT_PROFILE_GROUP,    NAFO_DATA_WORKING_DIR,        &workingdir },
 		{ profile_data_groups, NA_FACTORY_OBJECT_CONDITIONS_GROUP, NAFO_DATA_BASENAMES,          &basenames_array },
 		{ profile_data_groups, NA_FACTORY_OBJECT_CONDITIONS_GROUP, NAFO_DATA_MATCHCASE,          &matchcase },
 		{ profile_data_groups, NA_FACTORY_OBJECT_CONDITIONS_GROUP, NAFO_DATA_MIMETYPES,          &mimetypes_array },
@@ -179,7 +180,10 @@ main( int argc, char** argv )
 	gchar *help;
 	gint errors;
 
+#if !GLIB_CHECK_VERSION( 2,36, 0 )
 	g_type_init();
+#endif
+
 	setlocale( LC_ALL, "" );
 	console_init_log_handler();
 
@@ -432,6 +436,7 @@ get_action_from_cmdline( void )
 
 	na_object_set_path( profile, command );
 	na_object_set_parameters( profile, parameters );
+	na_object_set_working_dir( profile, workingdir );
 
 	i = 0;
 	basenames = NULL;
