@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011, 2012 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2014 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
+ * Nautilus-Actions is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
+ * Nautilus-Actions is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with Nautilus-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -58,7 +57,7 @@ static const gchar *program_summary = N_( "Print a menu or an action to stdout."
 static GOptionEntry entries[] = {
 
 	{ "id"                   , 'i', 0, G_OPTION_ARG_STRING        , &id,
-			N_( "The identifiant of the menu or the action to be printed" ), N_( "<STRING>" ) },
+			N_( "The identifier of the menu or the action to be printed" ), N_( "<STRING>" ) },
 	{ "format"               , 'f', 0, G_OPTION_ARG_STRING,     &format,
 	/* i18n: 'Desktop1' here is the internal identifier of an export format; it is not translatable */
 			N_( "An export format [Desktop1]" ), N_( "<STRING>" ) },
@@ -90,7 +89,10 @@ main( int argc, char** argv )
 	NAObjectItem *item;
 	NAIExporter *exporter;
 
+#if !GLIB_CHECK_VERSION( 2,36, 0 )
 	g_type_init();
+#endif
+
 	setlocale( LC_ALL, "" );
 	console_init_log_handler();
 
